# Veriteem
This package implements a Distributed Ledger Technology (DLT) based on Ethereum 
which provides a publicly readable ledger managed by a group of Ledger Guardians.
The implementation provides transaction processing for contracts, Proof of Authority
consensus, and management of Smart Contracts running on the ledger.

For more information about use of the package, please visit:

https://github.com/VerimatrixGen1/Veriteem/wiki
